@@ -16,7 +16,6 @@ file.findup = require('findup-sync');
 var YAML = require('js-yaml');
 var rimraf = require('rimraf');
 var iconv = require('iconv-lite');
-var pathIsAbsolute = require('path-is-absolute');
 var mkdirp = require('mkdirp').sync;
 
 // Windows?
@@ -242,12 +241,21 @@ file.readJSON = function(filepath, options) {
 };
 
 // Read a YAML file, parse its contents, return an object.
-file.readYAML = function(filepath, options) {
+file.readYAML = function(filepath, options, yamlOptions) {
+  if (!options) { options = {}; }
+  if (!yamlOptions) { yamlOptions = {}; }
+
   var src = file.read(filepath, options);
   var result;
   grunt.verbose.write('Parsing ' + filepath + '...');
   try {
-    result = YAML.load(src);
+    // use the recommended way of reading YAML files
+    // https://github.com/nodeca/js-yaml#safeload-string---options-
+    if (yamlOptions.unsafeLoad) {
+      result = YAML.load(src);
+    } else {
+      result = YAML.safeLoad(src);
+    }
     grunt.verbose.ok();
     return result;
   } catch (e) {
@@ -381,7 +389,15 @@ file.exists = function() {
 // True if the file is a symbolic link.
 file.isLink = function() {
   var filepath = path.join.apply(path, arguments);
-  return file.exists(filepath) && fs.lstatSync(filepath).isSymbolicLink();
+  try {
+    return fs.lstatSync(filepath).isSymbolicLink();
+  } catch (e) {
+    if (e.code === 'ENOENT') {
+      // The file doesn't exist, so it's not a symbolic link.
+      return false;
+    }
+    throw grunt.util.error('Unable to read "' + filepath + '" file (Error code: ' + e.code + ').', e);
+  }
 };
 
 // True if the path is a directory.
@@ -399,7 +415,7 @@ file.isFile = function() {
 // Is a given file path absolute?
 file.isPathAbsolute = function() {
   var filepath = path.join.apply(path, arguments);
-  return pathIsAbsolute(filepath);
+  return path.isAbsolute(filepath);
 };
 
 // Do all the specified paths refer to the same path?
